==> rt-3.6.3p1.tgz: libdata/perl5/site_perl/RT/Search/FromSQL.pm <==
# BEGIN BPS TAGGED BLOCK {{{
# 
# COPYRIGHT:
#  
# This software is Copyright (c) 1996-2006 Best Practical Solutions, LLC 
#                                          <jesse@bestpractical.com>
# 
# (Except where explicitly superseded by other copyright notices)
# 
# 
# LICENSE:
# 
# This work is made available to you under the terms of Version 2 of
# the GNU General Public License. A copy of that license should have
# been provided with this software, but in any event can be snarfed
# from www.gnu.org.
# 
# This work is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
# 
# 
# CONTRIBUTION SUBMISSION POLICY:
# 
# (The following paragraph is not intended to limit the rights granted
# to you to modify and distribute this software under the terms of
# the GNU General Public License and is only of importance to you if
# you choose to contribute your changes and enhancements to the
# community by submitting them to Best Practical Solutions, LLC.)
# 
# By intentionally submitting any modifications, corrections or
# derivatives to this work, or any other work intended for use with
# Request Tracker, to Best Practical Solutions, LLC, you confirm that
# you are the copyright holder for those contributions and you grant
# Best Practical Solutions,  LLC a nonexclusive, worldwide, irrevocable,
# royalty-free, perpetual, license to use, copy, create derivative
# works based on those contributions, and sublicense and distribute
# those contributions and any derivatives thereof.
# 
# END BPS TAGGED BLOCK }}}
=head1 NAME

  RT::Search::FromSQL

=head1 SYNOPSIS

=head1 DESCRIPTION

Find all tickets described by the SQL statement passed as an argument

=head1 METHODS


=begin testing

ok (require RT::Search::Generic);

=end testing


=cut

package RT::Search::FromSQL;

use strict;
use base qw(RT::Search::Generic);

=head2 Describe

Returns a localized string describing the module's function.

=cut

# {{{ sub Describe 
sub Describe  {
    my $self = shift;
    return ($self->loc("TicketSQL search module", ref $self));
}
# }}}

=head2 Prepare

The meat of the module.  Runs a search on its Tickets object, using
the SQL string described in its Argument object.  The Tickets object
is reduced to those tickets matching the SQL query.

=cut

# {{{ sub Prepare
sub Prepare  {
    my $self = shift;

    $self->TicketsObj->FromSQL($self->Argument);
    return(1);
}
# }}}

eval "require RT::Search::FromSQL_Vendor";
die $@ if ($@ && $@ !~ qr{^Can't locate RT/Search/FromSQL_Vendor.pm});
eval "require RT::Search::FromSQL_Local";
die $@ if ($@ && $@ !~ qr{^Can't locate RT/Search/FromSQL_Local.pm});

1;

==> rt-3.8.8p3.tgz: libdata/perl5/site_perl/RT/Search/FromSQL.pm <==
# BEGIN BPS TAGGED BLOCK {{{
# 
# COPYRIGHT:
# 
# This software is Copyright (c) 1996-2009 Best Practical Solutions, LLC
#                                          <jesse@bestpractical.com>
# 
# (Except where explicitly superseded by other copyright notices)
# 
# 
# LICENSE:
# 
# This work is made available to you under the terms of Version 2 of
# the GNU General Public License. A copy of that license should have
# been provided with this software, but in any event can be snarfed
# from www.gnu.org.
# 
# This work is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301 or visit their web page on the internet at
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.html.
# 
# 
# CONTRIBUTION SUBMISSION POLICY:
# 
# (The following paragraph is not intended to limit the rights granted
# to you to modify and distribute this software under the terms of
# the GNU General Public License and is only of importance to you if
# you choose to contribute your changes and enhancements to the
# community by submitting them to Best Practical Solutions, LLC.)
# 
# By intentionally submitting any modifications, corrections or
# derivatives to this work, or any other work intended for use with
# Request Tracker, to Best Practical Solutions, LLC, you confirm that
# you are the copyright holder for those contributions and you grant
# Best Practical Solutions,  LLC a nonexclusive, worldwide, irrevocable,
# royalty-free, perpetual, license to use, copy, create derivative
# works based on those contributions, and sublicense and distribute
# those contributions and any derivatives thereof.
# 
# END BPS TAGGED BLOCK }}}

=head1 NAME

  RT::Search::FromSQL

=head1 SYNOPSIS

=head1 DESCRIPTION

Find all tickets described by the SQL statement passed as an argument

=head1 METHODS




=cut

package RT::Search::FromSQL;

use strict;
use base qw(RT::Search);

=head2 Describe

Returns a localized string describing the module's function.

=cut

# {{{ sub Describe 
sub Describe  {
    my $self = shift;
    return ($self->loc("TicketSQL search module", ref $self));
}
# }}}

=head2 Prepare

The meat of the module.  Runs a search on its Tickets object, using
the SQL string described in its Argument object.  The Tickets object
is reduced to those tickets matching the SQL query.

=cut

# {{{ sub Prepare
sub Prepare  {
    my $self = shift;

    $self->TicketsObj->FromSQL($self->Argument);
    return(1);
}
# }}}

eval "require RT::Search::FromSQL_Vendor";
die $@ if ($@ && $@ !~ qr{^Can't locate RT/Search/FromSQL_Vendor.pm});
eval "require RT::Search::FromSQL_Local";
die $@ if ($@ && $@ !~ qr{^Can't locate RT/Search/FromSQL_Local.pm});

1;
